# -*- coding: utf-8 -*-


from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_WGunnar(object):
    def setupUi(self, WGunnar):
        WGunnar.setObjectName("WGunnar")
        WGunnar.resize(532, 778)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/roerik"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        WGunnar.setWindowIcon(icon)
        WGunnar.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(WGunnar)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_12 = QtWidgets.QLabel(WGunnar)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout.addWidget(self.label_12)
        self.deltaEdit = QtWidgets.QLineEdit(WGunnar)
        self.deltaEdit.setObjectName("deltaEdit")
        self.horizontalLayout.addWidget(self.deltaEdit)
        self.horizontalLayout_14.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_6 = QtWidgets.QLabel(WGunnar)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_2.addWidget(self.label_6)
        self.d0Edit = QtWidgets.QLineEdit(WGunnar)
        self.d0Edit.setObjectName("d0Edit")
        self.horizontalLayout_2.addWidget(self.d0Edit)
        self.horizontalLayout_14.addLayout(self.horizontalLayout_2)
        self.verticalLayout_2.addLayout(self.horizontalLayout_14)
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.label = QtWidgets.QLabel(WGunnar)
        self.label.setObjectName("label")
        self.horizontalLayout_12.addWidget(self.label)
        self.lambdaEdit = QtWidgets.QLineEdit(WGunnar)
        self.lambdaEdit.setObjectName("lambdaEdit")
        self.horizontalLayout_12.addWidget(self.lambdaEdit)
        self.horizontalLayout_15.addLayout(self.horizontalLayout_12)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_7 = QtWidgets.QLabel(WGunnar)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_3.addWidget(self.label_7)
        self.x0Edit = QtWidgets.QLineEdit(WGunnar)
        self.x0Edit.setObjectName("x0Edit")
        self.horizontalLayout_3.addWidget(self.x0Edit)
        self.horizontalLayout_15.addLayout(self.horizontalLayout_3)
        self.verticalLayout_2.addLayout(self.horizontalLayout_15)
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.label_2 = QtWidgets.QLabel(WGunnar)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_11.addWidget(self.label_2)
        self.alphaEdit = QtWidgets.QLineEdit(WGunnar)
        self.alphaEdit.setObjectName("alphaEdit")
        self.horizontalLayout_11.addWidget(self.alphaEdit)
        self.horizontalLayout_16.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_8 = QtWidgets.QLabel(WGunnar)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_4.addWidget(self.label_8)
        self.y0Edit = QtWidgets.QLineEdit(WGunnar)
        self.y0Edit.setObjectName("y0Edit")
        self.horizontalLayout_4.addWidget(self.y0Edit)
        self.horizontalLayout_16.addLayout(self.horizontalLayout_4)
        self.verticalLayout_2.addLayout(self.horizontalLayout_16)
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.label_3 = QtWidgets.QLabel(WGunnar)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_10.addWidget(self.label_3)
        self.betaEdit = QtWidgets.QLineEdit(WGunnar)
        self.betaEdit.setObjectName("betaEdit")
        self.horizontalLayout_10.addWidget(self.betaEdit)
        self.horizontalLayout_17.addLayout(self.horizontalLayout_10)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_9 = QtWidgets.QLabel(WGunnar)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_5.addWidget(self.label_9)
        self.omegaEdit = QtWidgets.QLineEdit(WGunnar)
        self.omegaEdit.setObjectName("omegaEdit")
        self.horizontalLayout_5.addWidget(self.omegaEdit)
        self.horizontalLayout_17.addLayout(self.horizontalLayout_5)
        self.verticalLayout_2.addLayout(self.horizontalLayout_17)
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_4 = QtWidgets.QLabel(WGunnar)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_9.addWidget(self.label_4)
        self.phixEdit = QtWidgets.QLineEdit(WGunnar)
        self.phixEdit.setObjectName("phixEdit")
        self.horizontalLayout_9.addWidget(self.phixEdit)
        self.horizontalLayout_18.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label_10 = QtWidgets.QLabel(WGunnar)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_6.addWidget(self.label_10)
        self.kappaEdit = QtWidgets.QLineEdit(WGunnar)
        self.kappaEdit.setObjectName("kappaEdit")
        self.horizontalLayout_6.addWidget(self.kappaEdit)
        self.horizontalLayout_18.addLayout(self.horizontalLayout_6)
        self.verticalLayout_2.addLayout(self.horizontalLayout_18)
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_5 = QtWidgets.QLabel(WGunnar)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_8.addWidget(self.label_5)
        self.phiyEdit = QtWidgets.QLineEdit(WGunnar)
        self.phiyEdit.setObjectName("phiyEdit")
        self.horizontalLayout_8.addWidget(self.phiyEdit)
        self.horizontalLayout_19.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_11 = QtWidgets.QLabel(WGunnar)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_7.addWidget(self.label_11)
        self.phiEdit = QtWidgets.QLineEdit(WGunnar)
        self.phiEdit.setObjectName("phiEdit")
        self.horizontalLayout_7.addWidget(self.phiEdit)
        self.horizontalLayout_19.addLayout(self.horizontalLayout_7)
        self.verticalLayout_2.addLayout(self.horizontalLayout_19)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_13 = QtWidgets.QLabel(WGunnar)
        self.label_13.setObjectName("label_13")
        self.verticalLayout.addWidget(self.label_13)
        self.ubmText = QtWidgets.QPlainTextEdit(WGunnar)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ubmText.sizePolicy().hasHeightForWidth())
        self.ubmText.setSizePolicy(sizePolicy)
        self.ubmText.setMaximumBlockCount(0)
        self.ubmText.setObjectName("ubmText")
        self.verticalLayout.addWidget(self.ubmText)
        self.verticalLayout_2.addLayout(self.verticalLayout)
        self.resTable = QtWidgets.QTableWidget(WGunnar)
        self.resTable.setObjectName("resTable")
        self.resTable.setColumnCount(3)
        self.resTable.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.resTable.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.resTable.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.resTable.setHorizontalHeaderItem(2, item)
        self.verticalLayout_2.addWidget(self.resTable)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.parButton = QtWidgets.QPushButton(WGunnar)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/open"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.parButton.setIcon(icon1)
        self.parButton.setObjectName("parButton")
        self.horizontalLayout_13.addWidget(self.parButton)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_13.addItem(spacerItem)
        self.exitButton = QtWidgets.QPushButton(WGunnar)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/exit"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.exitButton.setIcon(icon2)
        self.exitButton.setObjectName("exitButton")
        self.horizontalLayout_13.addWidget(self.exitButton)
        self.verticalLayout_2.addLayout(self.horizontalLayout_13)

        self.retranslateUi(WGunnar)
        QtCore.QMetaObject.connectSlotsByName(WGunnar)

    def retranslateUi(self, WGunnar):
        _translate = QtCore.QCoreApplication.translate
        WGunnar.setWindowTitle(_translate("WGunnar", "Hrœrekr Multiple Beam"))
        self.label_12.setText(_translate("WGunnar", "<html><head/><body><p>&Delta;</p></body></html>"))
        self.label_6.setText(_translate("WGunnar", "<html><head/><body><p>d<sub>0</sub></p></body></html>"))
        self.label.setText(_translate("WGunnar", "<html><head/><body><p>&lambda;</p></body></html>"))
        self.label_7.setText(_translate("WGunnar", "<html><head/><body><p>x<sub>0</sub></p></body></html>"))
        self.label_2.setText(_translate("WGunnar", "<html><head/><body><p>&alpha;</p></body></html>"))
        self.label_8.setText(_translate("WGunnar", "<html><head/><body><p>y<sub>0</sub></p></body></html>"))
        self.label_3.setText(_translate("WGunnar", "<html><head/><body><p>&beta;</p></body></html>"))
        self.label_9.setText(_translate("WGunnar", "<html><head/><body><p>&omega;</p></body></html>"))
        self.label_4.setText(_translate("WGunnar", "<html><head/><body><p>&phi;<sub>x</sub></p></body></html>"))
        self.label_10.setText(_translate("WGunnar", "<html><head/><body><p>&kappa;</p></body></html>"))
        self.label_5.setText(_translate("WGunnar", "<html><head/><body><p>&phi;<sub>y</sub></p></body></html>"))
        self.label_11.setText(_translate("WGunnar", "<html><head/><body><p>&phi;</p></body></html>"))
        self.label_13.setText(_translate("WGunnar", "UB matrix"))
        item = self.resTable.horizontalHeaderItem(0)
        item.setText(_translate("WGunnar", "(h, k, l)"))
        item = self.resTable.horizontalHeaderItem(1)
        item.setText(_translate("WGunnar", "(x, y)"))
        item = self.resTable.horizontalHeaderItem(2)
        item.setText(_translate("WGunnar", "ah"))
        self.parButton.setText(_translate("WGunnar", "Open .par file"))
        self.exitButton.setText(_translate("WGunnar", "Exit"))

from . import resources_rc
