# -*- coding: utf-8 -*-


from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_WSleuth(object):
    def setupUi(self, WSleuth):
        WSleuth.setObjectName("WSleuth")
        WSleuth.resize(970, 530)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/sleuth"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        WSleuth.setWindowIcon(icon)
        WSleuth.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout(WSleuth)
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.groupBox = QtWidgets.QGroupBox(WSleuth)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.x1SpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.x1SpinBox.setMaximum(65536)
        self.x1SpinBox.setObjectName("x1SpinBox")
        self.horizontalLayout.addWidget(self.x1SpinBox)
        self.horizontalLayout_6.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_2.addWidget(self.label_2)
        self.y1SpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.y1SpinBox.setMaximum(65536)
        self.y1SpinBox.setObjectName("y1SpinBox")
        self.horizontalLayout_2.addWidget(self.y1SpinBox)
        self.horizontalLayout_6.addLayout(self.horizontalLayout_2)
        self.verticalLayout.addLayout(self.horizontalLayout_6)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_3.addWidget(self.label_3)
        self.x2SpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.x2SpinBox.setMaximum(65536)
        self.x2SpinBox.setObjectName("x2SpinBox")
        self.horizontalLayout_3.addWidget(self.x2SpinBox)
        self.horizontalLayout_7.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_4.addWidget(self.label_4)
        self.y2SpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.y2SpinBox.setMaximum(65536)
        self.y2SpinBox.setObjectName("y2SpinBox")
        self.horizontalLayout_4.addWidget(self.y2SpinBox)
        self.horizontalLayout_7.addLayout(self.horizontalLayout_4)
        self.verticalLayout.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_9.addWidget(self.label_5)
        self.frameSpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.frameSpinBox.setMinimum(-1)
        self.frameSpinBox.setMaximum(65536)
        self.frameSpinBox.setObjectName("frameSpinBox")
        self.horizontalLayout_9.addWidget(self.frameSpinBox)
        self.horizontalLayout_10.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_6 = QtWidgets.QLabel(self.groupBox)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_8.addWidget(self.label_6)
        self.pmSpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.pmSpinBox.setSuffix("")
        self.pmSpinBox.setMinimum(0)
        self.pmSpinBox.setMaximum(65536)
        self.pmSpinBox.setObjectName("pmSpinBox")
        self.horizontalLayout_8.addWidget(self.pmSpinBox)
        self.horizontalLayout_10.addLayout(self.horizontalLayout_8)
        self.verticalLayout.addLayout(self.horizontalLayout_10)
        self.horizontalLayout_11.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_8 = QtWidgets.QLabel(self.groupBox)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_5.addWidget(self.label_8)
        self.dirLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.dirLineEdit.setObjectName("dirLineEdit")
        self.horizontalLayout_5.addWidget(self.dirLineEdit)
        self.dirButton = QtWidgets.QPushButton(self.groupBox)
        self.dirButton.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/folder"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.dirButton.setIcon(icon1)
        self.dirButton.setFlat(True)
        self.dirButton.setObjectName("dirButton")
        self.horizontalLayout_5.addWidget(self.dirButton)
        self.verticalLayout_2.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.label_7 = QtWidgets.QLabel(self.groupBox)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_13.addWidget(self.label_7)
        self.reLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.reLineEdit.setObjectName("reLineEdit")
        self.horizontalLayout_13.addWidget(self.reLineEdit)
        self.verticalLayout_2.addLayout(self.horizontalLayout_13)
        self.onlineCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.onlineCheckBox.setObjectName("onlineCheckBox")
        self.verticalLayout_2.addWidget(self.onlineCheckBox)
        self.horizontalLayout_11.addLayout(self.verticalLayout_2)
        self.verticalLayout_3.addLayout(self.horizontalLayout_11)
        self.intTable = QtWidgets.QTableWidget(self.groupBox)
        self.intTable.setObjectName("intTable")
        self.intTable.setColumnCount(0)
        self.intTable.setRowCount(0)
        self.verticalLayout_3.addWidget(self.intTable)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.runButton = QtWidgets.QPushButton(self.groupBox)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/run"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.runButton.setIcon(icon2)
        self.runButton.setObjectName("runButton")
        self.horizontalLayout_12.addWidget(self.runButton)
        self.stopButton = QtWidgets.QPushButton(self.groupBox)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/stop"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.stopButton.setIcon(icon3)
        self.stopButton.setObjectName("stopButton")
        self.horizontalLayout_12.addWidget(self.stopButton)
        self.saveButton = QtWidgets.QPushButton(self.groupBox)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/save"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.saveButton.setIcon(icon4)
        self.saveButton.setObjectName("saveButton")
        self.horizontalLayout_12.addWidget(self.saveButton)
        self.copyButton = QtWidgets.QPushButton(self.groupBox)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/copy"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.copyButton.setIcon(icon5)
        self.copyButton.setObjectName("copyButton")
        self.horizontalLayout_12.addWidget(self.copyButton)
        self.exitButton = QtWidgets.QPushButton(self.groupBox)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/exit"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.exitButton.setIcon(icon6)
        self.exitButton.setObjectName("exitButton")
        self.horizontalLayout_12.addWidget(self.exitButton)
        self.verticalLayout_3.addLayout(self.horizontalLayout_12)
        self.horizontalLayout_14.addWidget(self.groupBox)
        self.plotView = PlotWidget(WSleuth)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.plotView.sizePolicy().hasHeightForWidth())
        self.plotView.setSizePolicy(sizePolicy)
        self.plotView.setObjectName("plotView")
        self.horizontalLayout_14.addWidget(self.plotView)

        self.retranslateUi(WSleuth)
        QtCore.QMetaObject.connectSlotsByName(WSleuth)

    def retranslateUi(self, WSleuth):
        _translate = QtCore.QCoreApplication.translate
        WSleuth.setWindowTitle(_translate("WSleuth", "Sleuth"))
        self.groupBox.setTitle(_translate("WSleuth", "Parameters"))
        self.label.setText(_translate("WSleuth", "x1"))
        self.label_2.setText(_translate("WSleuth", "y1"))
        self.label_3.setText(_translate("WSleuth", "x2"))
        self.label_4.setText(_translate("WSleuth", "y2"))
        self.label_5.setText(_translate("WSleuth", "N"))
        self.label_6.setText(_translate("WSleuth", "<html><head/><body><p>&plusmn;</p></body></html>"))
        self.label_8.setText(_translate("WSleuth", "Folder"))
        self.label_7.setText(_translate("WSleuth", "Regexp"))
        self.onlineCheckBox.setText(_translate("WSleuth", "Online"))
        self.runButton.setText(_translate("WSleuth", "Run"))
        self.stopButton.setText(_translate("WSleuth", "Stop"))
        self.saveButton.setText(_translate("WSleuth", "Save"))
        self.copyButton.setText(_translate("WSleuth", "Copy"))
        self.exitButton.setText(_translate("WSleuth", "Exit"))

from pyqtgraph import PlotWidget
from . import resources_rc
