# -*- coding: utf-8 -*-


from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_WSnblToolBox(object):
    def setupUi(self, WSnblToolBox):
        WSnblToolBox.setObjectName("WSnblToolBox")
        WSnblToolBox.resize(612, 276)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/swiss"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        WSnblToolBox.setWindowIcon(icon)
        WSnblToolBox.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.gridLayout = QtWidgets.QGridLayout(WSnblToolBox)
        self.gridLayout.setObjectName("gridLayout")
        self.crysisButton = QtWidgets.QToolButton(WSnblToolBox)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/crysis"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.crysisButton.setIcon(icon1)
        self.crysisButton.setIconSize(QtCore.QSize(72, 72))
        self.crysisButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.crysisButton.setObjectName("crysisButton")
        self.gridLayout.addWidget(self.crysisButton, 0, 0, 1, 1)
        self.darthButton = QtWidgets.QToolButton(WSnblToolBox)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/darth"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.darthButton.setIcon(icon2)
        self.darthButton.setIconSize(QtCore.QSize(72, 72))
        self.darthButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.darthButton.setObjectName("darthButton")
        self.gridLayout.addWidget(self.darthButton, 0, 1, 1, 1)
        self.convertButton = QtWidgets.QToolButton(WSnblToolBox)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/convert"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.convertButton.setIcon(icon3)
        self.convertButton.setIconSize(QtCore.QSize(72, 72))
        self.convertButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.convertButton.setObjectName("convertButton")
        self.gridLayout.addWidget(self.convertButton, 0, 2, 1, 1)
        self.sigmasButton = QtWidgets.QToolButton(WSnblToolBox)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/scale"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.sigmasButton.setIcon(icon4)
        self.sigmasButton.setIconSize(QtCore.QSize(72, 72))
        self.sigmasButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.sigmasButton.setObjectName("sigmasButton")
        self.gridLayout.addWidget(self.sigmasButton, 0, 3, 1, 1)
        self.headExButton = QtWidgets.QToolButton(WSnblToolBox)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/header"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.headExButton.setIcon(icon5)
        self.headExButton.setIconSize(QtCore.QSize(72, 72))
        self.headExButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.headExButton.setObjectName("headExButton")
        self.gridLayout.addWidget(self.headExButton, 1, 0, 1, 1)
        self.sleuthButton = QtWidgets.QToolButton(WSnblToolBox)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/sleuth"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.sleuthButton.setIcon(icon6)
        self.sleuthButton.setIconSize(QtCore.QSize(72, 72))
        self.sleuthButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.sleuthButton.setObjectName("sleuthButton")
        self.gridLayout.addWidget(self.sleuthButton, 1, 1, 1, 1)
        self.roerikButton = QtWidgets.QToolButton(WSnblToolBox)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/roerik"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.roerikButton.setIcon(icon7)
        self.roerikButton.setIconSize(QtCore.QSize(72, 72))
        self.roerikButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.roerikButton.setObjectName("roerikButton")
        self.gridLayout.addWidget(self.roerikButton, 1, 2, 1, 1)
        self.infoButton = QtWidgets.QToolButton(WSnblToolBox)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/info"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.infoButton.setIcon(icon8)
        self.infoButton.setIconSize(QtCore.QSize(72, 72))
        self.infoButton.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.infoButton.setObjectName("infoButton")
        self.gridLayout.addWidget(self.infoButton, 1, 3, 1, 1)

        self.retranslateUi(WSnblToolBox)
        QtCore.QMetaObject.connectSlotsByName(WSnblToolBox)

    def retranslateUi(self, WSnblToolBox):
        _translate = QtCore.QCoreApplication.translate
        WSnblToolBox.setWindowTitle(_translate("WSnblToolBox", "SNBL Toolbox"))
        self.crysisButton.setToolTip(_translate("WSnblToolBox", "Crysis produces the need files for crysalis"))
        self.crysisButton.setStatusTip(_translate("WSnblToolBox", "Crysis produces the need files for crysalis"))
        self.crysisButton.setWhatsThis(_translate("WSnblToolBox", "Crysis produces the need files for crysalis"))
        self.crysisButton.setText(_translate("WSnblToolBox", "Crysis"))
        self.darthButton.setToolTip(_translate("WSnblToolBox", "Generate CCP4 file from a crysalis project"))
        self.darthButton.setStatusTip(_translate("WSnblToolBox", "Generate CCP4 file from a crysalis project"))
        self.darthButton.setWhatsThis(_translate("WSnblToolBox", "Generate CCP4 file from a crysalis project"))
        self.darthButton.setText(_translate("WSnblToolBox", "3DV"))
        self.convertButton.setToolTip(_translate("WSnblToolBox", "Convert the pilatus file to the other formats"))
        self.convertButton.setStatusTip(_translate("WSnblToolBox", "Convert the pilatus file to the other formats"))
        self.convertButton.setWhatsThis(_translate("WSnblToolBox", "Convert the pilatus file to the other formats"))
        self.convertButton.setText(_translate("WSnblToolBox", "Converter"))
        self.sigmasButton.setToolTip(_translate("WSnblToolBox", "Scale data from fit2d"))
        self.sigmasButton.setStatusTip(_translate("WSnblToolBox", "Scale data from fit2d"))
        self.sigmasButton.setWhatsThis(_translate("WSnblToolBox", "Scale data from fit2d"))
        self.sigmasButton.setText(_translate("WSnblToolBox", "σ-scaler"))
        self.headExButton.setToolTip(_translate("WSnblToolBox", "Extract information from cbf headers"))
        self.headExButton.setStatusTip(_translate("WSnblToolBox", "Extract information from cbf headers"))
        self.headExButton.setWhatsThis(_translate("WSnblToolBox", "Extract information from cbf headers"))
        self.headExButton.setText(_translate("WSnblToolBox", "HeadEx"))
        self.sleuthButton.setToolTip(_translate("WSnblToolBox", "Search intensity through the folder"))
        self.sleuthButton.setStatusTip(_translate("WSnblToolBox", "Search intensity through the folder"))
        self.sleuthButton.setWhatsThis(_translate("WSnblToolBox", "Search intensity through the folder"))
        self.sleuthButton.setText(_translate("WSnblToolBox", "Sleuth"))
        self.roerikButton.setToolTip(_translate("WSnblToolBox", "Calculate possible beam scattering"))
        self.roerikButton.setStatusTip(_translate("WSnblToolBox", "Calculate possible beam scattering"))
        self.roerikButton.setWhatsThis(_translate("WSnblToolBox", "Calculate possible beam scattering"))
        self.roerikButton.setText(_translate("WSnblToolBox", "Hrœrekr"))
        self.infoButton.setToolTip(_translate("WSnblToolBox", "Information"))
        self.infoButton.setStatusTip(_translate("WSnblToolBox", "Information"))
        self.infoButton.setWhatsThis(_translate("WSnblToolBox", "Information"))
        self.infoButton.setText(_translate("WSnblToolBox", "Info"))

from . import resources_rc
